# Generated by Django 4.2.6 on 2023-10-10 20:06

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='SystemMail',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('from_name', models.CharField(max_length=255, verbose_name='From')),
                ('to_addr', models.TextField(help_text='E-Mail addresses, comma separated', verbose_name='To')),
                ('subject', models.CharField(default='', max_length=255, verbose_name='Subject')),
                ('body', models.TextField(default='', verbose_name='Mail Body')),
                ('sent', models.BooleanField(default=False, verbose_name='E-Mail sent')),
                ('error', models.TextField(blank=True, null=True, verbose_name='Errors')),
            ],
            options={
                'db_table': 'system_mail',
            },
        ),
    ]
