<div id="content-right-header" class="is-flex is-flex-wrap-wrap">
    {% block header %}{% endblock %}
</div>

<div id="content-right" style="overflow-y: auto; height: 100%;">
    {% block content %}{% endblock %}
</div>
